<?php

namespace Drupal\scanner\Plugin;

use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;

/**
 * Provides a Scanner plugin manager.
 *
 * @see \Drupal\Core\Scanner\Annotation\Scanner
 * @see \Drupal\Core\Scanner\ScannerPluginInterface
 * @see plugin_api
 */
class ScannerPluginManager extends DefaultPluginManager {

  /**
   * Constructs a ScannerPluginManager object.
   * 
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct('Plugin/Scanner', $namespaces, $module_handler, 'Drupal\scanner\Plugin\ScannerPluginInterface', 'Drupal\scanner\Annotation\Scanner');
    $this->alterInfo('scanner_info');
    $this->setCacheBackend($cache_backend, 'scanner');
  }

}
